"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.filesChanged = exports.hash = void 0;
const path_1 = __importDefault(require("path"));
// included here in preference to goldstack utils-sh to avoid circular dependency
const shelljs_1 = __importDefault(require("shelljs"));
const console_1 = require("console");
const isDebug = process.env.GOLDSTACK_DEBUG || process.env.DEBUG;
// included here to avoid circular dependency
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const debug = (msg) => {
    if (isDebug) {
        console.log(msg);
    }
};
const exec = (cmd, params) => {
    const res = shelljs_1.default.exec(cmd, { silent: params === null || params === void 0 ? void 0 : params.silent });
    if (!res || res.code != 0) {
        shelljs_1.default.echo(res.stdout);
        shelljs_1.default.echo(res.stderr);
        throw new Error(`Error running '${cmd}'`);
    }
    return res.stdout;
};
const hash = () => {
    if (!shelljs_1.default.which('git')) {
        throw new Error('git is not installed or not available as command.');
    }
    const hash = exec('git rev-parse --short HEAD', { silent: true }).trim();
    return hash;
};
exports.hash = hash;
const filesChanged = () => {
    const headDiff = shelljs_1.default.exec('git diff "HEAD..HEAD^1" --quiet -- . ');
    const headChanged = headDiff.code !== 0;
    if (headChanged) {
        debug('Detected change against HEAD^1 in ' + path_1.default.resolve('.'));
    }
    const fileDiff = shelljs_1.default.exec('git diff --quiet -- . ');
    const fileChanged = fileDiff.code !== 0;
    if (fileChanged) {
        debug('Detected uncommited change in ' + path_1.default.resolve('.'));
    }
    if (headChanged || fileChanged) {
        return true;
    }
    else {
        return false;
    }
};
exports.filesChanged = filesChanged;
const run = (args) => {
    (0, console_1.assert)(args[3] === '--exec');
    const [, , , , ...execCommands] = args;
    const execCommand = execCommands.join(' ');
    if (args[2] === 'changed') {
        if ((0, exports.filesChanged)()) {
            const res = shelljs_1.default.exec(execCommand);
            if (res.code !== 0) {
                console.log(res.stdout);
                console.log(res.stderr);
                console.log('Error when running "' + execCommand + '"');
                process.exit(res.code);
            }
            else {
                console.log(res.stdout);
            }
        }
        else {
            console.log('No file changes detected in ' + path_1.default.resolve('.'));
        }
    }
    else {
        console.log('Please provide argument changed.');
        process.exit(1);
    }
};
exports.run = run;
//# sourceMappingURL=utilsGit.js.map